@@ -4,20 +4,17 @@ Methods that don't fit in their own file
 import os
 from collections.abc import Coroutine
 from pathlib import Path
-from typing import Any, AsyncGenerator, Optional, Union
+from typing import Any, Optional, Union
 
 import aiofiles
 
-from .datatypes import ArchiveTypes
-from .exceptions import (AlreadyExistsException, BufferedProcessError,
-                         GitException)
-from .helpers import ensure_path, subprocess_run, subprocess_run_buffered
+from .exceptions import AlreadyExistsException, GitException
+from .helpers import ensure_path, subprocess_run
 
 __all__ = [
     "get_version", "init_repo",
     "clone_repo", "get_description",
     "set_description", "run_maintenance",
-    "get_archive", "get_archive_buffered",
 ]
 
 
@@ -137,56 +134,6 @@ async def run_maintenance(git_repo: Union[Path, str]):
         raise GitException(process.stderr.decode())
 
 
-async def get_archive(
-        git_repo: Union[Path, str],
-        archive_type: ArchiveTypes,
-        tree_ish: str = "HEAD") -> bytes:
-    """
-    get a archive of a git repo
-
-        :param git_repo: Where the repo is
-        :param archive_type: What archive type will be created
-        :param tree_ish: What commit/branch to save, defaults to "HEAD"
-        :raises GitException: Error to do with git
-        :return: The content of the archive ready to write to a file
-    """
-    # this allows for strings to be passed
-    if isinstance(archive_type, ArchiveTypes):
-        archive_type = archive_type.value
-    process = await subprocess_run(
-        ["git", "-C", str(git_repo), "archive", f"--format={archive_type}", tree_ish],
-    )
-    if process.returncode != 0:
-        raise GitException(process.stderr.decode())
-    return process.stdout
-
-
-async def get_archive_buffered(
-        git_repo: Union[Path, str],
-        archive_type: ArchiveTypes,
-        tree_ish: str = "HEAD") -> AsyncGenerator[bytes, None]:
-    """
-    get a archive of a git repo, but using a buffered read
-
-        :param git_repo: Where the repo is
-        :param archive_type: What archive type will be created
-        :param tree_ish: What commit/branch to save, defaults to "HEAD"
-        :raises GitException: Error to do with git
-        :yield: Each read content section
-    """
-    # this allows for strings to be passed
-    if isinstance(archive_type, ArchiveTypes):
-        archive_type = archive_type.value
-
-    args = ["git", "-C", str(git_repo), "archive", f"--format={archive_type}", tree_ish]
-
-    try:
-        async for content in subprocess_run_buffered(args):
-            yield content
-    except BufferedProcessError as err:
-        raise GitException(err.args[0].decode()) from err
-
-
 async def add_to_staged(git_repo: Union[Path, str], path: str, *extra_paths: tuple[str]):
     """
     Add files to the repository staging area
